Mopinion API - Python Client
==========================================

.. image:: https://img.shields.io/badge/License-MIT-yellow.svg
    :target: https://github.com/mopinion/mopinion-python-api/blob/master/LICENSE

.. image:: https://readthedocs.org/projects/mopinion-python-api/badge/?version=latest
    :target: https://mopinion-python-api.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://github.com/mopinion/mopinion-python-api/workflows/Test%20Suite/badge.svg/
    :alt: GitHub Actions

API client library for the `Mopinion Data API <https://developer.mopinion.com/api/>`_.

mopinion-python-api provides functionality for authentication, authorization and requesting resources.
It comes with an easy, beautiful and elegant way of interacting with our API.

`Read the docs <https://mopinion-python-api.readthedocs.io/en/latest/>`_ for further information.
